
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.29.1',
    'branch_nick': 'release-1.29-LTS',
    'revision_id': '37fa7156f7985def1bdd95d4ff07c0c127390650',
    'revno': 11893
}
